@@ -12,9 +12,29 @@ from pyrfuniverse.attributes.humanbody_attr import HumanbodyAttr
 from pyrfuniverse.attributes.graspsim_attr import GraspSimAttr
 from pyrfuniverse.attributes.digit_attr import DigitAttr
 from pyrfuniverse.attributes.pointcloud_attr import PointCloudAttr
+from pyrfuniverse.attributes.fallingcloth_attr import FallingClothAttr
 from pyrfuniverse.attributes.custom_attr import CustomAttr
 
-# 新增脚本的命名规则必须是 *_attr,此处名称必须与Unity中保持一致
+try:
+    from pyrfuniverse.attributes.omplmanager_attr import OmplManagerAttr
+except:
+    pass
+
 __all__ = [
-    'base_attr', 'camera_attr', 'activelightsensor_attr', 'collider_attr', 'controller_attr', 'gameobject_attr', 'rigidbody_attr', 'cloth_attr', 'softbody_attr', 'humanbody_attr', 'graspsim_attr', 'digit_attr', 'pointcloud_attr', 'custom_attr'
+    "base_attr",
+    "camera_attr",
+    "activelightsensor_attr",
+    "collider_attr",
+    "controller_attr",
+    "gameobject_attr",
+    "rigidbody_attr",
+    "cloth_attr",
+    "softbody_attr",
+    "humanbody_attr",
+    "graspsim_attr",
+    "digit_attr",
+    "pointcloud_attr",
+    "fallingcloth_attr",
+    "custom_attr",
+    "omplmanager_attr",
 ]
