@@ -1,6 +1,4 @@
 from pyrfuniverse.envs.multi_agent import navigation_env
 from pyrfuniverse.envs.multi_agent.cleaner_env import CleanerEnv
 
-__all__ = [
-    'navigation_env', 'CleanerEnv'
-]
+__all__ = ["navigation_env", "CleanerEnv"]
