@@ -10,9 +10,8 @@ import uuid
 
 
 class CollisionAndCleaningDetectionChannel(SideChannel):
-
     def __init__(self, agents, num_floors=64):
-        super().__init__(uuid.UUID('bee25cbc-09e2-11ec-9e67-18c04d443e7d'))
+        super().__init__(uuid.UUID("bee25cbc-09e2-11ec-9e67-18c04d443e7d"))
         self._agent_collisions = {}
         self._agent_cleanings = {}
         self._num_collisions = 0
@@ -29,9 +28,9 @@ class CollisionAndCleaningDetectionChannel(SideChannel):
             num_collisions = msg.read_int32()
             num_cleanings = msg.read_int32()
 
-            if agent_name == '':
+            if agent_name == "":
                 continue
-            if agent_name[-7:] == '(Clone)':
+            if agent_name[-7:] == "(Clone)":
                 agent_name = agent_name[:-7]
             self._agent_collisions[agent_name] += num_collisions
             self._agent_cleanings[agent_name] += num_cleanings
@@ -68,26 +67,28 @@ class CollisionAndCleaningDetectionChannel(SideChannel):
 
 
 class CleanerEnv(RFUniverseGymWrapper):
-    metadata = {'render.modes': ['human']}
+    metadata = {"render.modes": ["human"]}
 
     def __init__(
-            self,
-            asset_bundle_file,
-            max_episode_length=100,
-            reset_on_collision=True,
-            velocity_reward=False,
-            obs_type='multi',
-            grid_reward_per_step=False,
-            num_agents=3,
-            strength=1000,
-            collision_multiplier=5,
-            num_floors=64,
-            executable_file=None,
+        self,
+        asset_bundle_file,
+        max_episode_length=100,
+        reset_on_collision=True,
+        velocity_reward=False,
+        obs_type="multi",
+        grid_reward_per_step=False,
+        num_agents=3,
+        strength=1000,
+        collision_multiplier=5,
+        num_floors=64,
+        executable_file=None,
     ):
         self.num_agents = num_agents
         self.num_floors = num_floors
-        self.agent_names = ['agent_' + str(i) for i in range(self.num_agents)]
-        self.channel = CollisionAndCleaningDetectionChannel(self.agent_names, self.num_floors)
+        self.agent_names = ["agent_" + str(i) for i in range(self.num_agents)]
+        self.channel = CollisionAndCleaningDetectionChannel(
+            self.agent_names, self.num_floors
+        )
         super().__init__(
             executable_file=executable_file,
             custom_channels=[self.channel],
@@ -103,22 +104,33 @@ class CleanerEnv(RFUniverseGymWrapper):
         self.obs_type = obs_type
         self.grid_reward_per_step = grid_reward_per_step
 
-        self.agent_name = 'CleanRobot'
+        self.agent_name = "CleanRobot"
         self.y_offset = 0.1
         self.reset_agent_min_distance = 1.0
         self.world_range_low = np.array([-3, self.y_offset, -3])
         self.world_range_high = np.array([3, self.y_offset, 3])
         self.seed()
 
-        self.action_space = spaces.Box(low=-1, high=1, shape=(2 * self.num_agents,), dtype=np.float32)
+        self.action_space = spaces.Box(
+            low=-1, high=1, shape=(2 * self.num_agents,), dtype=np.float32
+        )
 
-        if self.obs_type == 'multi':
-            self.observation_space = spaces.Dict({
-                'agent_obs': spaces.Box(low=-np.inf, high=np.inf, shape=(4 * self.num_agents,), dtype=float),
-                'floor_obs': spaces.MultiBinary(self.num_floors)
-            })
+        if self.obs_type == "multi":
+            self.observation_space = spaces.Dict(
+                {
+                    "agent_obs": spaces.Box(
+                        low=-np.inf,
+                        high=np.inf,
+                        shape=(4 * self.num_agents,),
+                        dtype=float,
+                    ),
+                    "floor_obs": spaces.MultiBinary(self.num_floors),
+                }
+            )
         else:
-            self.observation_space = spaces.Box(low=-np.inf, high=np.inf, shape=(4 * self.num_agents,), dtype=float)
+            self.observation_space = spaces.Box(
+                low=-np.inf, high=np.inf, shape=(4 * self.num_agents,), dtype=float
+            )
         self._env_setup()
         self.t = 0
         self.num_clean_grids = 0
@@ -146,7 +158,7 @@ class CleanerEnv(RFUniverseGymWrapper):
         if not self.reset_on_collision:
             reward += -1 * num_collisions * self.collision_multiplier
 
-        info = {'is_success': total_num_clean_grids > self.num_floors * 0.8}
+        info = {"is_success": total_num_clean_grids > self.num_floors * 0.8}
         self.t += 1
         self.num_clean_grids = total_num_clean_grids
 
@@ -165,7 +177,9 @@ class CleanerEnv(RFUniverseGymWrapper):
         positions = []
         for i in range(self.num_agents):
             while True:
-                agent_position = self.np_random.uniform(self.world_range_low, self.world_range_high)
+                agent_position = self.np_random.uniform(
+                    self.world_range_low, self.world_range_high
+                )
                 if self._check_reset_position_legality(positions, agent_position):
                     break
             positions.append(agent_position.copy())
@@ -182,62 +196,63 @@ class CleanerEnv(RFUniverseGymWrapper):
         self.np_random, seed = seeding.np_random(seed)
         return [seed]
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         self._step()
 
     def _env_setup(self):
         for i in range(self.num_agents):
-            agent_position = self.np_random.uniform(self.world_range_low, self.world_range_high)
+            agent_position = self.np_random.uniform(
+                self.world_range_low, self.world_range_high
+            )
             self.asset_channel.set_action(
-                'LoadRigidbodyWithName',
+                "LoadRigidbodyWithName",
                 filename=self.asset_bundle_file,
-                name=self.agent_name + ' ' + str(i),
+                name=self.agent_name + " " + str(i),
                 replace_name=self.agent_names[i],
-                position=list(agent_position)
+                position=list(agent_position),
             )
             self._step()
 
     def _get_obs(self):
         agent_obs = np.array([])
         for i in range(self.num_agents):
-            agent_position = self.rigidbody_channel.data[i]['position']
-            agent_velocity = self.rigidbody_channel.data[i]['velocity']
+            agent_position = self.rigidbody_channel.data[i]["position"]
+            agent_velocity = self.rigidbody_channel.data[i]["velocity"]
             # We ignore y-axis
-            this_agent_obs = np.array([agent_position[0], agent_position[2], agent_velocity[0], agent_velocity[2]])
+            this_agent_obs = np.array(
+                [
+                    agent_position[0],
+                    agent_position[2],
+                    agent_velocity[0],
+                    agent_velocity[2],
+                ]
+            )
             agent_obs = np.concatenate((agent_obs, this_agent_obs))
 
         floor_obs = self.channel.get_cleaning_states().astype(np.int8)
 
-        if self.obs_type == 'multi':
-            return {
-                'agent_obs': agent_obs.copy(),
-                'floor_obs': floor_obs.copy()[0]
-            }
+        if self.obs_type == "multi":
+            return {"agent_obs": agent_obs.copy(), "floor_obs": floor_obs.copy()[0]}
         else:
             return agent_obs.copy()
 
     def _set_agent_position(self, index, position):
         self.rigidbody_channel.set_action(
-            'SetTransform',
-            index=index,
-            position=list(position),
-            rotation=[0, 0, 0]
+            "SetTransform", index=index, position=list(position), rotation=[0, 0, 0]
         )
         self._step()
 
     def _set_agent_force(self, index, force):
-        self.rigidbody_channel.set_action(
-            'AddForce',
-            index=index,
-            force=force
-        )
+        self.rigidbody_channel.set_action("AddForce", index=index, force=force)
         self._step()
 
     def _get_total_velocity(self):
         total_velocity = 0
         for i in range(self.num_agents):
-            velocity = self.rigidbody_channel.data[i]['velocity']
-            total_velocity += np.linalg.norm(np.array([velocity[0], velocity[2]]), axis=-1)
+            velocity = self.rigidbody_channel.data[i]["velocity"]
+            total_velocity += np.linalg.norm(
+                np.array([velocity[0], velocity[2]]), axis=-1
+            )
 
         return total_velocity
 
