@@ -1,4 +1,5 @@
-from pyrfuniverse.envs import RFUniverseGymGoalWrapper
+from pyrfuniverse.envs.gym_goal_wrapper_env import RFUniverseGymGoalWrapper
+
 # from pyrfuniverse.utils import RFUniverseController
 import numpy as np
 from gym import spaces
@@ -7,17 +8,17 @@ import copy
 
 
 class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
-    metadata = {'render.modes': ['human']}
+    metadata = {"render.modes": ["human"]}
     height_offset = 0.01
 
     def __init__(
-            self,
-            asset_bundle_file,
-            executable_file=None,
-            reward_type='sparse',
-            tolerance=0.05,
-            object_xz_range=0.055,
-            object_rotation_range=180,
+        self,
+        asset_bundle_file,
+        executable_file=None,
+        reward_type="sparse",
+        tolerance=0.05,
+        object_xz_range=0.055,
+        object_rotation_range=180,
     ):
         super().__init__(
             executable_file=executable_file,
@@ -28,10 +29,16 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
         self.tolerance = tolerance
         self.object_xz_range = object_xz_range
         self.object_rotation_range = object_rotation_range
-        self.object_range_low = np.array([-object_xz_range, self.height_offset, -object_xz_range])
-        self.object_range_high = np.array([object_xz_range, self.height_offset, object_xz_range])
+        self.object_range_low = np.array(
+            [-object_xz_range, self.height_offset, -object_xz_range]
+        )
+        self.object_range_high = np.array(
+            [object_xz_range, self.height_offset, object_xz_range]
+        )
         self.asset_bundle_file = asset_bundle_file
-        self.ik_controller = RFUniverseController('franka', base_pos=np.array([-0.6, 0, 0]))
+        self.ik_controller = RFUniverseController(
+            "franka", base_pos=np.array([-0.6, 0, 0])
+        )
         self.t = 0
 
         self.has_loaded_object = False
@@ -39,19 +46,25 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
         self.seed()
         self._load_object()
 
-        self.action_space = spaces.Box(
-            low=-1, high=1, shape=(4,), dtype=np.float32
-        )
+        self.action_space = spaces.Box(low=-1, high=1, shape=(4,), dtype=np.float32)
         obs = self._get_obs()
-        self.observation_space = spaces.Dict({
-            'observation': spaces.Box(-np.inf, np.inf, shape=obs['observation'].shape, dtype=np.float32),
-            'desired_goal': spaces.Box(-np.inf, np.inf, shape=obs['desired_goal'].shape, dtype=np.float32),
-            'achieved_goal': spaces.Box(-np.inf, np.inf, shape=obs['achieved_goal'].shape, dtype=np.float32)
-        })
+        self.observation_space = spaces.Dict(
+            {
+                "observation": spaces.Box(
+                    -np.inf, np.inf, shape=obs["observation"].shape, dtype=np.float32
+                ),
+                "desired_goal": spaces.Box(
+                    -np.inf, np.inf, shape=obs["desired_goal"].shape, dtype=np.float32
+                ),
+                "achieved_goal": spaces.Box(
+                    -np.inf, np.inf, shape=obs["achieved_goal"].shape, dtype=np.float32
+                ),
+            }
+        )
 
     def step(self, action: np.ndarray):
         pos_ctrl = action[:3] * 0.05
-        curr_pos = np.array(self.articulation_channel.data[1]['positions'][3])
+        curr_pos = np.array(self.articulation_channel.data[1]["positions"][3])
         pos_ctrl = curr_pos + pos_ctrl
         joint_positions = self.ik_controller.calculate_ik_recursive(pos_ctrl)
 
@@ -65,10 +78,8 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
 
         obs = self._get_obs()
         done = False
-        info = {
-            'is_success': self._check_success(obs)
-        }
-        reward = self.compute_reward(obs['achieved_goal'], obs['desired_goal'], info)
+        info = {"is_success": self._check_success(obs)}
+        reward = self.compute_reward(obs["achieved_goal"], obs["desired_goal"], info)
 
         return obs, reward, done, info
 
@@ -83,7 +94,7 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
         grasp_position = self._get_grasp_position()
         joint_positions = self.ik_controller.calculate_ik_recursive(grasp_position)
         self.articulation_channel.set_action(
-            'SetJointPositionDirectly',
+            "SetJointPositionDirectly",
             index=0,
             joint_positions=list(joint_positions),
         )
@@ -95,42 +106,53 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
         self.np_random, seed = seeding.np_random(seed)
         return [seed]
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         self._step()
 
     def compute_reward(self, achieved_goal, desired_goal, info):
         distance = self._compute_goal_distance(achieved_goal, desired_goal)
-        if self.reward_type == 'sparse':
+        if self.reward_type == "sparse":
             return -(distance > self.tolerance).astype(np.float32)
         else:
             return -distance
 
     def _get_obs(self):
-        gripper_position = np.array(self.articulation_channel.data[1]['positions'][3])
-        gripper_velocity = np.array(self.articulation_channel.data[1]['velocities'][3])
+        gripper_position = np.array(self.articulation_channel.data[1]["positions"][3])
+        gripper_velocity = np.array(self.articulation_channel.data[1]["velocities"][3])
         gripper_width = self._get_gripper_width()
 
-        panda_obs = np.concatenate((gripper_position, gripper_velocity, [gripper_width]))
+        panda_obs = np.concatenate(
+            (gripper_position, gripper_velocity, [gripper_width])
+        )
 
-        grasp_position = np.array(self.obi_cloth_with_grasping_channel.data[0]['grasp_position'])
-        grasp_rotation = np.array(self.obi_cloth_with_grasping_channel.data[0]['grasp_rotation'])
-        grasp_velocity = np.array(self.obi_cloth_with_grasping_channel.data[0]['grasp_velocity'])
-        grasp_angular_vel = np.array(self.obi_cloth_with_grasping_channel.data[0]['grasp_angular_vel'])
+        grasp_position = np.array(
+            self.obi_cloth_with_grasping_channel.data[0]["grasp_position"]
+        )
+        grasp_rotation = np.array(
+            self.obi_cloth_with_grasping_channel.data[0]["grasp_rotation"]
+        )
+        grasp_velocity = np.array(
+            self.obi_cloth_with_grasping_channel.data[0]["grasp_velocity"]
+        )
+        grasp_angular_vel = np.array(
+            self.obi_cloth_with_grasping_channel.data[0]["grasp_angular_vel"]
+        )
         achieved_goal = grasp_position.copy()
 
-        object_obs = np.concatenate((grasp_position, grasp_rotation, grasp_velocity, grasp_angular_vel))
+        object_obs = np.concatenate(
+            (grasp_position, grasp_rotation, grasp_velocity, grasp_angular_vel)
+        )
 
         obs = np.concatenate((panda_obs, object_obs))
 
         return {
-            'observation': obs.copy(),
-            'achieved_goal': achieved_goal.copy(),
-            'desired_goal': self.goal.copy()
+            "observation": obs.copy(),
+            "achieved_goal": achieved_goal.copy(),
+            "desired_goal": self.goal.copy(),
         }
 
     def _generate_random_float(self, min: float, max: float) -> float:
-        assert min < max, \
-            'Min value is {}, while max value is {}.'.format(min, max)
+        assert min < max, "Min value is {}, while max value is {}.".format(min, max)
         random_float = np.random.rand()
         random_float = random_float * (max - min) + min
 
@@ -138,7 +160,7 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
 
     def _set_franka_joints(self, a: np.ndarray):
         self.articulation_channel.set_action(
-            'SetJointPosition',
+            "SetJointPosition",
             index=0,
             joint_positions=list(a[0:7]),
         )
@@ -146,19 +168,21 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
 
         a[7] = -1 * a[7] / 2
         self.articulation_channel.set_action(
-            'SetJointPosition',
+            "SetJointPosition",
             index=1,
             joint_positions=[a[7], a[7]],
         )
         self._step()
 
     def _get_gripper_width(self):
-        gripper_joint_positions = copy.deepcopy(self.articulation_channel.data[1]['joint_positions'])
+        gripper_joint_positions = copy.deepcopy(
+            self.articulation_channel.data[1]["joint_positions"]
+        )
         return -1 * (gripper_joint_positions[0] + gripper_joint_positions[1])
 
     def _check_success(self, obs):
-        achieved_goal = obs['achieved_goal']
-        desired_goal = obs['desired_goal']
+        achieved_goal = obs["achieved_goal"]
+        desired_goal = obs["desired_goal"]
         distance = self._compute_goal_distance(achieved_goal, desired_goal)
 
         return (distance < self.tolerance).astype(np.float32)
@@ -168,36 +192,43 @@ class FrankaClothFoldEnv(RFUniverseGymGoalWrapper):
         return np.linalg.norm(goal_a - goal_b, axis=-1)
 
     def _load_object(self):
-        assert self.asset_bundle_file is not None, \
-            'There must be an asset bundle file to load.'
+        assert (
+            self.asset_bundle_file is not None
+        ), "There must be an asset bundle file to load."
 
-        object_name = 'Obi Solver For Grasp'
+        object_name = "Obi Solver For Grasp"
         position = self.np_random.uniform(self.object_range_low, self.object_range_high)
-        rotation = [0, self._generate_random_float(-self.object_rotation_range, self.object_rotation_range), 0]
+        rotation = [
+            0,
+            self._generate_random_float(
+                -self.object_rotation_range, self.object_rotation_range
+            ),
+            0,
+        ]
 
         self.asset_channel.set_action(
-            'LoadObiClothWithGrasping',
+            "LoadObiClothWithGrasping",
             filename=self.asset_bundle_file,
             name=object_name,
             position=position,
-            rotation=rotation
+            rotation=rotation,
         )
         self._step()
         self.has_loaded_object = True
-        self.goal = np.array(self.obi_cloth_with_grasping_channel.data[0]['target_position'])
+        self.goal = np.array(
+            self.obi_cloth_with_grasping_channel.data[0]["target_position"]
+        )
 
     def _destroy_object(self):
-        self.obi_cloth_with_grasping_channel.set_action(
-            'Destroy',
-            index=0
-        )
+        self.obi_cloth_with_grasping_channel.set_action("Destroy", index=0)
         self._step()
         self.has_loaded_object = False
         self.goal = None
 
     def _get_grasp_position(self):
-        assert self.has_loaded_object, \
-            'No object loaded.'
-        grasp_position = np.array(self.obi_cloth_with_grasping_channel.data[0]['grasp_position'])
+        assert self.has_loaded_object, "No object loaded."
+        grasp_position = np.array(
+            self.obi_cloth_with_grasping_channel.data[0]["grasp_position"]
+        )
 
         return grasp_position
