@@ -1,4 +1,4 @@
-from pyrfuniverse.envs import RFUniverseGymGoalWrapper
+from pyrfuniverse.envs.gym_goal_wrapper_env import RFUniverseGymGoalWrapper
 import numpy as np
 from gym import spaces
 from gym.utils import seeding
@@ -6,59 +6,69 @@ import copy
 
 
 class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
-    metadata = {'render.modes': ['human']}
+    metadata = {"render.modes": ["human"]}
     # height_offset is just the object width / 2, which is the object's stable height value.
     height_offset = 0.025
 
     def __init__(
-            self,
-            max_episode_length,
-            reward_type,
-            tolerance,
-            load_object,
-            target_in_air,
-            block_gripper,
-            target_xz_range,
-            target_y_range,
-            object_xz_range,
-            seed=1234,
-            executable_file=None,
-            scene_file=None,
-            asset_bundle_file=None,
-            assets: list = []
-
+        self,
+        max_episode_length,
+        reward_type,
+        tolerance,
+        load_object,
+        target_in_air,
+        block_gripper,
+        target_xz_range,
+        target_y_range,
+        object_xz_range,
+        seed=1234,
+        executable_file=None,
+        scene_file=None,
+        asset_bundle_file=None,
+        assets: list = [],
     ):
-        super().__init__(
-            executable_file,
-            scene_file,
-            assets=assets
-        )
+        super().__init__(executable_file, scene_file, assets=assets)
         self.max_steps = max_episode_length
         self.reward_type = reward_type
         self.tolerance = tolerance
         self.load_object = load_object
         self.target_in_air = target_in_air
         self.block_gripper = block_gripper
-        self.goal_range_low = np.array([-target_xz_range, self.height_offset, -target_xz_range])
-        self.goal_range_high = np.array([target_xz_range, target_y_range, target_xz_range])
-        self.object_range_low = np.array([-object_xz_range, self.height_offset, -object_xz_range])
-        self.object_range_high = np.array([object_xz_range, self.height_offset, object_xz_range])
+        self.goal_range_low = np.array(
+            [-target_xz_range, self.height_offset, -target_xz_range]
+        )
+        self.goal_range_high = np.array(
+            [target_xz_range, target_y_range, target_xz_range]
+        )
+        self.object_range_low = np.array(
+            [-object_xz_range, self.height_offset, -object_xz_range]
+        )
+        self.object_range_high = np.array(
+            [object_xz_range, self.height_offset, object_xz_range]
+        )
         self.asset_bundle_file = asset_bundle_file
 
         self.seed(seed)
         self._env_setup()
+        self.init_pos = [0.15, 0.3, 0]
         self.t = 0
         self.goal = self._sample_goal()
-        self.action_space = spaces.Box(
-            low=-1, high=1, shape=(4,), dtype=np.float32
-        )
+        self.action_space = spaces.Box(low=-1, high=1, shape=(4,), dtype=np.float32)
 
         obs = self._get_obs()
-        self.observation_space = spaces.Dict({
-            'observation': spaces.Box(-np.inf, np.inf, shape=obs['observation'].shape, dtype=np.float32),
-            'desired_goal': spaces.Box(-np.inf, np.inf, shape=obs['desired_goal'].shape, dtype=np.float32),
-            'achieved_goal': spaces.Box(-np.inf, np.inf, shape=obs['achieved_goal'].shape, dtype=np.float32)
-        })
+        self.observation_space = spaces.Dict(
+            {
+                "observation": spaces.Box(
+                    -np.inf, np.inf, shape=obs["observation"].shape, dtype=np.float32
+                ),
+                "desired_goal": spaces.Box(
+                    -np.inf, np.inf, shape=obs["desired_goal"].shape, dtype=np.float32
+                ),
+                "achieved_goal": spaces.Box(
+                    -np.inf, np.inf, shape=obs["achieved_goal"].shape, dtype=np.float32
+                ),
+            }
+        )
 
     def step(self, action: np.ndarray):
         """
@@ -67,19 +77,23 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
         """
         # print(action)
         pos_ctrl = action[:3] * 0.05
-        curr_pos = np.array(self.instance_channel.data[9658740]['positions'][3])
+        curr_pos = np.array(self.attrs[9658740].data["positions"][3])
         # print(curr_pos)
         pos_ctrl = curr_pos + pos_ctrl
 
         # print(pos_ctrl)
-        self.instance_channel.set_action(
-            "IKTargetDoMove",
-            id=965874,
+        # self.instance_channel.set_action(
+        #     "IKTargetDoMove",
+        #     id=965874,
+        #     position=[pos_ctrl[0], pos_ctrl[1], pos_ctrl[2]],
+        #     duration=0.1,
+        #     speed_based=True
+        # )
+        self.attrs[965874].IKTargetDoMove(
             position=[pos_ctrl[0], pos_ctrl[1], pos_ctrl[2]],
             duration=0.1,
-            speed_based=True
+            speed_based=True,
         )
-
         if self.block_gripper:
             self._set_gripper_width(0)
         else:
@@ -94,10 +108,8 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
 
         obs = self._get_obs()
         done = False
-        info = {
-            'is_success': self._check_success(obs)
-        }
-        reward = self.compute_reward(obs['achieved_goal'], obs['desired_goal'], info)
+        info = {"is_success": self._check_success(obs)}
+        reward = self.compute_reward(obs["achieved_goal"], obs["desired_goal"], info)
 
         if self.t == self.max_steps:
             done = True
@@ -106,7 +118,6 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
 
     def reset(self):
         super().reset()
-        self.env.reset()
         self.t = 0
         self.goal = self._sample_goal()
         object_pos = None
@@ -124,21 +135,13 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
         # self.ik_controller.reset()
 
         if self.load_object and self.target_in_air:
-            # Move the robot arm to the object's position, which can accelerate training process
-            # joint_positions = self.ik_controller.calculate_ik(object_pos)
-            self.instance_channel.set_action(
-                "IKTargetDoMove",
-                id=965874,
-                position=[object_pos[0], object_pos[1] + 0.1, object_pos[2]],
+            self.attrs[965874].IKTargetDoMove(
+                position=[self.init_pos[0], self.init_pos[1], self.init_pos[2]],
                 duration=0,
                 speed_based=False,
             )
             self._step()
-            self.instance_channel.set_action(
-                'SetJointPositionDirectly',
-                id=9658740,
-                joint_positions=[0.04, 0.04],
-            )
+            self.attrs[9658740].SetJointPositionDirectly(joint_positions=[0.04, 0.04])
             self._step()
 
         self._step()
@@ -149,39 +152,45 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
         self.np_random, seed = seeding.np_random(seed)
         return [seed]
 
-    def render(self, mode='human'):
+    def render(self, mode="human"):
         self._step()
 
     def compute_reward(self, achieved_goal, desired_goal, info):
         distance = self._compute_goal_distance(achieved_goal, desired_goal)
-        if self.reward_type == 'sparse':
+        if self.reward_type == "sparse":
             return -(distance > self.tolerance).astype(np.float32)
         else:
             return -distance
 
     def _get_obs(self):
-        gripper_position = np.array(self.instance_channel.data[9658740]['positions'][3])
-        gripper_velocity = np.array(self.instance_channel.data[9658740]['velocities'][3])
+        gripper_position = np.array(self.attrs[9658740].data["positions"][3])
+        gripper_velocity = np.array(self.attrs[9658740].data["velocities"][3])
         gripper_width = self._get_gripper_width()
         # gripper_joint_position = np.array(self.articulation_channel.data[1]['joint_positions'])
         # gripper_joint_velocity = np.array(self.articulation_channel.data[1]['joint_velocities'])
 
-        panda_obs = np.concatenate((gripper_position, gripper_velocity, [gripper_width]))
+        panda_obs = np.concatenate(
+            (gripper_position, gripper_velocity, [gripper_width])
+        )
 
         if self.load_object:
-            object_position = np.array(self.instance_channel.data[0]['position'])
-            object_rotation = np.array(self.instance_channel.data[0]['rotation'])
-            object_velocity = np.array(self.instance_channel.data[0]['velocity'])
-            object_angular_vel = np.array(self.instance_channel.data[0]['angular_vel'])
+            object_position = np.array(self.attrs[0].data["position"])
+            object_rotation = np.array(self.attrs[0].data["rotation"])
+            object_velocity = np.array(self.attrs[0].data["velocity"])
+            object_angular_vel = np.array(self.attrs[0].data["angular_vel"])
             # object_rel_pos = object_position - gripper_position
             # object_velocity = object_velocity - gripper_velocity
             achieved_goal = object_position.copy()
         else:
             # object_position = object_rotation = object_velocity = object_angular_vel = object_rel_pos = np.zeros(0)
-            object_position = object_rotation = object_velocity = object_angular_vel = np.zeros(0)
+            object_position = (
+                object_rotation
+            ) = object_velocity = object_angular_vel = np.zeros(0)
             achieved_goal = gripper_position.copy()
 
-        object_obs = np.concatenate((object_position, object_rotation, object_velocity, object_angular_vel))
+        object_obs = np.concatenate(
+            (object_position, object_rotation, object_velocity, object_angular_vel)
+        )
 
         # obs = np.concatenate(
         #     [gripper_position, object_position, object_rel_pos, gripper_joint_position, object_rotation,
@@ -190,41 +199,26 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
         obs = np.concatenate((panda_obs, object_obs))
 
         return {
-            'observation': obs.copy(),
-            'achieved_goal': achieved_goal.copy(),
-            'desired_goal': self.goal.copy()
+            "observation": obs.copy(),
+            "achieved_goal": achieved_goal.copy(),
+            "desired_goal": self.goal.copy(),
         }
 
     def _env_setup(self):
         if self.load_object:
-            self.asset_channel.set_action(
-                'InstanceObject',
-                name='Rigidbody_Box',
-                id=0
+            self.InstanceObject(name="Rigidbody_Box", id=0)
+            self.attrs[0].SetTransform(
+                position=[0, self.height_offset, 0], scale=[0.05, 0.05, 0.05]
             )
-            self.instance_channel.set_action(
-                'SetTransform',
-                id=0,
-                position=[0, self.height_offset, 0],
-                scale=[0.05, 0.05, 0.05],
-            )
-        self.instance_channel.set_action(
-            "SetIKTargetOffset",
-            id=965874,
-            position=[0, 0.105, 0],
-        )
-        self.instance_channel.set_action(
-            "IKTargetDoRotate",
-            id=965874,
-            vector3=[0, 45, 180],
-            duration=0,
-            speed_based=False,
+
+        self.attrs[965874].SetIKTargetOffset(position=[0, 0.105, 0])
+        self.attrs[965874].IKTargetDoRotate(
+            rotation=[0, 45, 180], duration=0, speed_based=False
         )
         self._step()
 
     def _generate_random_float(self, min: float, max: float) -> float:
-        assert min < max, \
-            'Min value is {}, while max value is {}.'.format(min, max)
+        assert min < max, "Min value is {}, while max value is {}.".format(min, max)
         random_float = np.random.rand()
         random_float = random_float * (max - min) + min
 
@@ -232,19 +226,17 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
 
     def _set_gripper_width(self, w: float):
         w = w / 2
-        self.instance_channel.set_action(
-            'SetJointPosition',
-            id=9658740,
-            joint_positions=[w, w],
-        )
+        self.attrs[9658740].SetJointPosition(joint_positions=[w, w])
 
     def _get_gripper_width(self) -> float:
-        gripper_joint_positions = copy.deepcopy(self.instance_channel.data[9658740]['joint_positions'])
+        gripper_joint_positions = copy.deepcopy(
+            self.attrs[9658740].data["joint_positions"]
+        )
         return -1 * (gripper_joint_positions[0] + gripper_joint_positions[1])
 
     def _check_success(self, obs):
-        achieved_goal = obs['achieved_goal']
-        desired_goal = obs['desired_goal']
+        achieved_goal = obs["achieved_goal"]
+        desired_goal = obs["desired_goal"]
         distance = self._compute_goal_distance(achieved_goal, desired_goal)
 
         return (distance < self.tolerance).astype(np.float32)
@@ -253,7 +245,6 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
         assert goal_a.shape == goal_b.shape
         return np.linalg.norm(goal_a - goal_b, axis=-1)
 
-
     def _sample_goal(self):
         if self.load_object:
             goal = np.array([0.0, 0.4, 0.0])
@@ -267,13 +258,9 @@ class FrankaRoboticsEnv(RFUniverseGymGoalWrapper):
         return goal.copy()
 
     def _reset_object(self):
-        object_pos = self.np_random.uniform(self.object_range_low, self.object_range_high)
-
-        self.instance_channel.set_action(
-            'SetTransform',
-            id=0,
-            position=list(object_pos),
-            rotation=[0, 0, 0]
+        object_pos = self.np_random.uniform(
+            self.object_range_low, self.object_range_high
         )
+        self.attrs[0].SetTransform(position=list(object_pos), rotation=[0, 0, 0])
         self._step()
         return object_pos.copy()
