@@ -2,14 +2,13 @@ from pyrfuniverse.envs.robotics import FrankaRoboticsEnv
 
 
 class FrankaPushEnv(FrankaRoboticsEnv):
-
     def __init__(
         self,
         executable_file,
         max_episode_length,
         reward_type,
         asset_bundle_file=None,
-        seed=None
+        seed=None,
     ):
         super().__init__(
             executable_file=executable_file,
@@ -23,5 +22,5 @@ class FrankaPushEnv(FrankaRoboticsEnv):
             target_xz_range=0.15,
             target_y_range=0.02,
             object_xz_range=0.15,
-            asset_bundle_file=asset_bundle_file
+            asset_bundle_file=asset_bundle_file,
         )
