@@ -1,5 +1,5 @@
 from pyrfuniverse.envs.tobor_robotics.tobor_push_pull_env import ToborPushPullEnv
 
 __all__ = [
-    'ToborPushPullEnv',
+    "ToborPushPullEnv",
 ]
